==> applet-service-1.0.0-vg-20210810.074113-19-sources.jar: com/bizvane/appletservice/models/vo/MemberOpenCardStoreVo.java <==
package com.bizvane.appletservice.models.vo;

public class MemberOpenCardStoreVo {
    private String storeName;
    private String cityName;
    private String storePhone;
    private String detailedAddress;
    private String lng;
    private String lat;
    private String distance;
    private String isExclusive;
    private String memberCode;
    private Long sysBrandId;
    private Long sysStoreId;
    private Long sysCompanyId;
    private String searchValue;
    //判断是否需要筛选自己的门店
    private Integer type;
    private Integer isWholeStore;

    private Integer pageNum = 1;
    private Integer pageSize = 20;

    public Integer getIsWholeStore() {
        return isWholeStore;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public void setIsWholeStore(Integer isWholeStore) {
        this.isWholeStore = isWholeStore;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getStorePhone() {
        return storePhone;
    }

    public void setStorePhone(String storePhone) {
        this.storePhone = storePhone;
    }

    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }

    public String getLng() {
        return lng;
    }

    public void setLng(String lng) {
        this.lng = lng;
    }

    public String getLat() {
        return lat;
    }

    public void setLat(String lat) {
        this.lat = lat;
    }

    public String getDistance() {
        return distance;
    }

    public void setDistance(String distance) {
        this.distance = distance;
    }

    public String getIsExclusive() {
        return isExclusive;
    }

    public void setIsExclusive(String isExclusive) {
        this.isExclusive = isExclusive;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getSysStoreId() {
        return sysStoreId;
    }

    public void setSysStoreId(Long sysStoreId) {
        this.sysStoreId = sysStoreId;
    }

    public String getSearchValue() {
        return searchValue;
    }

    public void setSearchValue(String searchValue) {
        this.searchValue = searchValue;
    }

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}

==> applet-service-1.5.2-vg-20221208.024427-15-sources.jar: com/bizvane/appletservice/models/vo/MemberOpenCardStoreVo.java <==
package com.bizvane.appletservice.models.vo;

public class MemberOpenCardStoreVo {
    private String storeName;
    private String cityName;
    private String storePhone;
    private String detailedAddress;
    private String lng;
    private String lat;
    private String distance;
    private String isExclusive;
    private String memberCode;
    private Long sysBrandId;
    private Long sysStoreId;
    private Long sysCompanyId;
    private String searchValue;
    //判断是否需要筛选自己的门店
    private Integer type;
    private Integer isWholeStore;

    private Integer pageNum = 1;
    private Integer pageSize = 20;

    //中奖记录ID
    private Long mktActivityPrizeRecordId;
    private Integer physicalExtractionType;

    public Integer getIsWholeStore() {
        return isWholeStore;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public void setIsWholeStore(Integer isWholeStore) {
        this.isWholeStore = isWholeStore;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getStorePhone() {
        return storePhone;
    }

    public void setStorePhone(String storePhone) {
        this.storePhone = storePhone;
    }

    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }

    public String getLng() {
        return lng;
    }

    public void setLng(String lng) {
        this.lng = lng;
    }

    public String getLat() {
        return lat;
    }

    public void setLat(String lat) {
        this.lat = lat;
    }

    public String getDistance() {
        return distance;
    }

    public void setDistance(String distance) {
        this.distance = distance;
    }

    public String getIsExclusive() {
        return isExclusive;
    }

    public void setIsExclusive(String isExclusive) {
        this.isExclusive = isExclusive;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getSysStoreId() {
        return sysStoreId;
    }

    public void setSysStoreId(Long sysStoreId) {
        this.sysStoreId = sysStoreId;
    }

    public String getSearchValue() {
        return searchValue;
    }

    public void setSearchValue(String searchValue) {
        this.searchValue = searchValue;
    }

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Long getMktActivityPrizeRecordId() {
        return mktActivityPrizeRecordId;
    }

    public void setMktActivityPrizeRecordId(Long mktActivityPrizeRecordId) {
        this.mktActivityPrizeRecordId = mktActivityPrizeRecordId;
    }

    public Integer getPhysicalExtractionType() {
        return physicalExtractionType;
    }

    public void setPhysicalExtractionType(Integer physicalExtractionType) {
        this.physicalExtractionType = physicalExtractionType;
    }
}
